Nxpy Test
=========

You can install the library with pip::

    pip install nxpy-test

*Nxpy Test* provides helpers for the implementation of ``unittest`` based tests.

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/test.html>`_.
